/**
 * Maps base doc
 */
import { ChildProperty } from '@syncfusion/ej2-base';
import { LabelPosition, Alignment, HighLightMode, SelectionMode, LabelIntersectAction, LabelPlacement } from '../utils/enum';
import { LabelAlignment, LegendShape, LegendPosition, LegendMode, LegendOrientation } from '../utils/enum';
import { BorderModel, FontModel, SubTitleSettingsModel, ColorMappingModel, CommonTitleSettingsModel } from './base-model';
import { Location } from '../utils/helper';
/**
 * Configures the borders in the maps.
 */
export declare type MarkerShape = 'Circle' | 'Rectangle' | 'Triangle' | 'Diamond' | 'Cross' | 'HorizontalLine' | 'VerticalLine' | 'Pentagon' | 'InvertedTriangle' | 'Image';
export declare class Border extends ChildProperty<Border> {
    /**
     * The color of the border that accepts value in hex and rgba as a valid CSS color string.
     * @default '#808080'
     */
    color: string;
    /**
     * The width of the border in pixels.
     * @default 0
     */
    width: number;
}
/**
 * Configures the treemap margin.
 */
export declare class Margin extends ChildProperty<Margin> {
    /**
     * Left margin in pixels.
     * @default 10
     */
    left: number;
    /**
     * Right margin in pixels.
     * @default 10
     */
    right: number;
    /**
     * Top margin in pixels.
     * @default 10
     */
    top: number;
    /**
     * Bottom margin in pixels.
     * @default 10
     */
    bottom: number;
}
/**
 * Configures the fonts in treemap.
 */
export declare class Font extends ChildProperty<Font> {
    /**
     * Font size for the text.
     * @default null
     */
    size: string;
    /**
     * Color for the text.
     * @default null
     */
    color: string;
    /**
     * fontFamily for the text.
     * @default ''
     */
    fontFamily: string;
    /**
     * FontWeight for the text.
     * @default 'Normal'
     */
    fontWeight: string;
    /**
     * FontStyle for the text.
     * @default 'Normal'
     */
    fontStyle: string;
    /**
     * Opacity for the text.
     * @default 1
     */
    opacity: number;
}
/**
 * To configure title of the maps.
 */
export declare class CommonTitleSettings extends ChildProperty<CommonTitleSettings> {
    /**
     * To customize the text of the title.
     * @default ''
     */
    text: string;
    /**
     * To customize title description for the accessibility.
     * @default ''
     */
    description: string;
}
/**
 * To configure subtitle of the maps.
 */
export declare class SubTitleSettings extends CommonTitleSettings {
    /**
     * Options for customizing title styles of the Maps.
     */
    textStyle: FontModel;
    /**
     * Options for customize the text alignment.
     * @default 'Center'
     */
    alignment: Alignment;
}
/**
 * To configure title of the maps.
 */
export declare class TitleSettings extends CommonTitleSettings {
    /**
     * Options for customizing title styles of the Maps.
     */
    textStyle: FontModel;
    /**
     * Options for customize the text alignment.
     * @default 'Center'
     */
    alignment: Alignment;
    /**
     * To configure sub title of maps.
     */
    subtitleSettings: SubTitleSettingsModel;
}
export declare class ColorMapping extends ChildProperty<ColorMapping> {
    /**
     * Specifies the from
     * @default null
     */
    from: number;
    /**
     * Specifies the to
     * @default null
     */
    to: number;
    /**
     * specifies the color
     * @default null
     */
    color: string;
    /**
     * Specifies the label text.
     * @default null
     */
    label: string;
    /**
     * Specifies the value
     * @default null
     */
    value: string | number;
    /**
     * Specifies the minOpacity
     * @default null
     */
    minOpacity: number;
    /**
     * maxOpacity
     * @default null
     */
    maxOpacity: number;
}
/**
 * Configures the legend settings.
 */
export declare class LegendSettings extends ChildProperty<LegendSettings> {
    /**
     * Toggle the legend visibility.
     * @default false
     */
    visible: boolean;
    /**
     * Customize the legend mode.
     * @default 'Default'
     */
    mode: LegendMode;
    /**
     * Customize the legend background
     * @default 'transparent'
     */
    background: string;
    /**
     * Customize the legend shape.
     * @default 'Circle'
     */
    shape: LegendShape;
    /**
     * Customize the legend width.
     * @default ''
     */
    width: string;
    /**
     * Customize the legend height.
     * @default ''
     */
    height: string;
    /**
     * Options for customize the legend text.
     */
    textStyle: FontModel;
    /**
     * Specifies the legend shape color
     * @default null
     */
    fill: string;
    /**
     * Customize the shape width.
     * @default 15
     */
    shapeWidth: number;
    /**
     * Customize the shape height.
     * @default 15
     */
    shapeHeight: number;
    /**
     * Customize the shape padding
     * @default 10
     */
    shapePadding: number;
    /**
     * Specifies the images url.
     * @default null
     */
    imageUrl: string;
    /**
     * Options for customizing the color and width of the legend border.
     */
    border: BorderModel;
    /**
     * Options for customizing the color and width of the shape border.
     */
    shapeBorder: BorderModel;
    /**
     * To configure the title of the legend.
     */
    title: CommonTitleSettingsModel;
    /**
     * Options for customizing text styles of the legend.
     */
    titleStyle: FontModel;
    /**
     * Customize the legend position of the maps.
     * @default 'Bottom'
     */
    position: LegendPosition;
    /**
     * Customize the legend items placed
     * @default 'None'
     */
    orientation: LegendOrientation;
    /**
     * Inverted pointer for interactive legend
     * @default false
     */
    invertedPointer: boolean;
    /**
     * To place the label position for interactive legend.
     * @default 'After'
     */
    labelPosition: LabelPlacement;
    /**
     * Specifies the label intersect action.
     * @default 'None'
     */
    labelDisplayMode: LabelIntersectAction;
    /**
     * Customize the legend alignment.
     * @default 'Center'
     */
    alignment: Alignment;
    /**
     * Customize the legend placed by given x and y values.
     */
    location: Location;
}
export declare class InitialDrillSettings extends ChildProperty<InitialDrillSettings> {
    /**
     * Specifies the initial rendering level.
     * @default null
     */
    groupIndex: number;
    /**
     * Specifies the initial rendering name.
     * @default null
     */
    groupName: string;
}
export declare class LeafItemSettings extends ChildProperty<LeafItemSettings> {
    /**
     * Specifies the fill color for leaf items.
     * @default '#808080'
     */
    fill: string;
    /**
     * Items rendering with random colors.
     * @default false
     */
    autoFill: boolean;
    /**
     * Specifies the border
     */
    border: BorderModel;
    /**
     * Specifies the item gap.
     * @default 0
     */
    gap: number;
    /**
     * Specifies the padding.
     * @default 10
     */
    padding: number;
    /**
     * Specifies the opacity for color.
     * @default 1
     */
    opacity: number;
    /**
     * To show or hide the labels
     * @default true
     */
    showLabels: boolean;
    /**
     * Specifies the field name from the dataSource.
     * @default null
     */
    labelPath: string;
    /**
     * Specifies the label format.
     * @default null
     */
    labelFormat: string;
    /**
     * Specifies the alignment of label.
     * @default 'TopLeft'
     */
    labelPosition: LabelPosition;
    /**
     * Customize the label style.
     */
    labelStyle: FontModel;
    /**
     * Specifies the label template.
     * @default null
     */
    labelTemplate: string;
    /**
     * Specifies the alignment of template.
     * @default 'Center'
     */
    templatePosition: LabelPosition;
    /**
     * Specifies the label intersect action.
     * @default 'Trim'
     */
    interSectAction: LabelAlignment;
    /**
     * Specifies the colorMapping
     */
    colorMapping: ColorMappingModel[];
}
export declare class TooltipSettings extends ChildProperty<TooltipSettings> {
    /**
     * To enable or disable the Tooltip.
     * @default false
     */
    visible: boolean;
    /**
     * To specifies the template for tooltip.
     * @default ''
     */
    template: string;
    /**
     * Specifies the format by given ${data}
     * @default null
     */
    format: string;
    /**
     * To fill the tooltip background.
     * @default '#000816'
     */
    fill: string;
    /**
     * Specifies the opacity for fill.
     * @default 0.75
     */
    opacity: number;
    /**
     * Specifies the marker shapes.
     * @default '[Circle]'
     */
    markerShapes: MarkerShape[];
    /**
     * Specifies the tooltip border.
     */
    border: BorderModel;
    /**
     * Specifies the text style.
     */
    textStyle: FontModel;
}
export declare class SelectionSettings extends ChildProperty<SelectionSettings> {
    /**
     * To enable or disable the selection
     * @default false
     */
    enable: boolean;
    /**
     * To specifies the selection color
     * @default '#808080'
     */
    fill: string;
    /**
     * To specified the opacity of color.
     * @default '0.5'
     */
    opacity: string;
    /**
     * To specifies the border
     */
    border: BorderModel;
    /**
     * To specifies the selection mode.
     * @default 'Item'
     */
    mode: SelectionMode;
}
export declare class HighlightSettings extends ChildProperty<HighlightSettings> {
    /**
     * To enable or disable the highlight.
     * @default false
     */
    enable: boolean;
    /**
     * To specifies the highlight color.
     * @default '#808080'
     */
    fill: string;
    /**
     * To specified the opacity of color.
     * @default '0.5'
     */
    opacity: string;
    /**
     * To specifies the border
     */
    border: BorderModel;
    /**
     * To specifies the highlight mode.
     * @default 'Item'
     */
    mode: HighLightMode;
}
/**
 * Options for customizing the tree map levels.
 */
export declare class LevelSettings extends ChildProperty<LevelSettings> {
    /**
     * Specifies the field name from the dataSource.
     * @default null
     */
    groupPath: string;
    /**
     * Specifies the padding.
     * @default 0
     */
    groupGap: number;
    /**
     * Specifies the padding.
     * @default 10
     */
    groupPadding: number;
    /**
     * Specifies the border
     */
    border: BorderModel;
    /**
     * Specifies the background of level.
     * @default '#808080'
     */
    fill: string;
    /**
     * Items rendering with random colors.
     * @default false
     */
    autoFill: boolean;
    /**
     * Specifies the opacity for color.
     * @default 1
     */
    opacity: number;
    /**
     * To Show or hide the header in level.
     * @default true
     */
    showHeader: boolean;
    /**
     * To specifies the height of header.
     * @default 20
     */
    headerHeight: number;
    /**
     * Specifies the template for header rendering.
     * @default null
     */
    headerTemplate: string;
    /**
     * Specifies the header format.
     * @default null
     */
    headerFormat: string;
    /**
     * Customize the text alignment
     * @default 'Near'
     */
    headerAlignment: Alignment;
    /**
     * Customize the header style.
     */
    headerStyle: FontModel;
    /**
     * Specifies the label position in level.
     * @default 'TopLeft'
     */
    templatePosition: LabelPosition;
    /**
     * Specifies the colorMapping
     */
    colorMapping: ColorMappingModel[];
}
